/**
 * Default tool parameters used in xpanderAI tool configuration.
 *
 * These parameters define the structure of request payloads for tools, including
 * query, path, and body parameters, as well as specifying required fields for
 * each parameter type.
 */
export declare const DEFAULT_TOOL_PARAMETERS: Readonly<{
    /** Specifies the type of tool parameters structure. */
    type: "object";
    /** List of required top-level parameters. */
    required: never[];
    /** Detailed properties of tool parameters. */
    properties: {
        /** Query parameters for the tool, structured as an object. */
        query_params: {
            type: string;
            properties: {};
            required: never[];
        };
        /** Path parameters for the tool, structured as an object. */
        path_params: {
            type: string;
            properties: {};
            required: never[];
        };
        /** Body parameters for the tool, structured as an object. */
        body_params: {
            type: string;
            properties: {};
            required: never[];
        };
    };
}>;
/** Prefix for identifying local tools in xpanderAI. */
export declare const LOCAL_TOOL_PREFIX = "xpLocal_";
export declare const AGENT_FINISH_TOOL_ID = "xpfinish-agent-execution-finished";
