import { Agents } from './agents/AgentsController';
import { Configuration } from './Configuration';
import { ToolCall } from './tools/ToolCall';
import { LLMProvider } from '../constants/llmProvider';
/**
 * XpanderClient provides methods for configuring and interacting with xpanderAI tools,
 * managing agents, and extracting tool calls from LLM responses.
 */
export declare class XpanderClient {
    /**
     * Extracts tool calls from an LLM response based on the specified LLM provider.
     * @param llmResponse - The LLM response to analyze for tool calls.
     * @param llmProvider - The LLM provider, defaults to OPEN_AI.
     * @returns An array of tool calls extracted from the LLM response.
     * @throws Error if the specified LLM provider is not supported.
     */
    static extractToolCalls(llmResponse: any, llmProvider?: LLMProvider): ToolCall[];
    /**
     * Filters and retrieves local tool calls from a given list of tool calls.
     * @param toolCalls - The list of tool calls to filter.
     * @returns An array of tool calls that are of type LOCAL.
     */
    static retrievePendingLocalToolCalls(toolCalls: ToolCall[]): ToolCall[];
    /** Configuration settings for the xpanderAI client. */
    configuration: Configuration;
    /** Instance of Agents to manage xpanderAI agents. */
    agents: Agents;
    /**
     * Constructs a new XpanderClient instance.
     * @param params - An object containing the parameters for the XpanderClient.
     * @param params.apiKey - The API key for the agent.
     * @param params.baseUrl - The base URL for the agent, defaults to DEFAULT_BASE_URL.
     * @param params.organizationId - Organization id (if needed).
     * @param params.should_reset_cache - Use this when you want to refresh the in-memory cache for each client initialization.
     * @throws Will throw an error if an invalid API key is specified.
     */
    constructor(apiKey: string, baseUrl?: any, organizationId?: string, should_reset_cache?: boolean);
}
