import { Agent } from './Agent';
import { AgentType } from '../../types/agents';
import { Configuration } from '../Configuration';
import { UnloadedAgent } from './UnloadedAgent';
/**
 * Manages a collection of Agent instances in xpanderAI, providing methods to list,
 * retrieve, and initialize agents, including custom agents.
 */
export declare class Agents {
    configuration: Configuration;
    /** Collection of Agent instances managed by this class. */
    agentsList: UnloadedAgent[];
    /**
     * Constructs an instance of the Agents manager.
     *
     * @param configuration - Configuration settings for managing agents.
     */
    constructor(configuration: Configuration);
    /**
     * Retrieves the list of agents from the API and populates the local agents list.
     *
     * @returns An array of Agent instances.
     */
    list(): UnloadedAgent[];
    /**
     * Retrieves a specific agent by its ID and initializes it.
     *
     * @param agentId - The unique identifier of the agent to retrieve.
     * @returns The requested Agent instance.
     */
    get(agentId: string): Agent;
    /**
     * @function create
     * @description Creates a new agent with the given name and type.
     * @param {string} name - The name of the agent to be created.
     * @param {AgentType} [type=AgentType.Regular] - The type of the agent, defaults to Regular.
     * @returns {Agent} The created agent's details.
     * @throws {Error} If the creation process fails.
     * @memberof xpanderAI
     */
    create(name: string, type?: AgentType): Agent;
}
