import { Agent } from '.';
import { AgentStatus } from '../../types';
import { Base } from '../base';
import { Configuration } from '../Configuration';
/**
 * Represents an unloaded agent in the xpander.ai system.
 * Used to reference agents that are not yet fully loaded.
 */
export declare class UnloadedAgent extends Base {
    private configuration;
    id: string;
    name: string;
    status: AgentStatus;
    organizationId: string;
    /**
     * Creates a new UnloadedAgent instance.
     *
     * @param configuration - The configuration instance used for loading the agent.
     * @param id - The unique identifier of the agent.
     * @param name - The name of the agent.
     * @param status - The current status of the agent.
     * @param organizationId - The ID of the organization to which the agent belongs.
     */
    constructor(configuration: Configuration, id: string, name: string, status: AgentStatus, organizationId: string);
    /**
     * Loads the full Agent instance from the xpander.ai system using its ID.
     *
     * @returns The fully loaded Agent instance.
     */
    load(): Agent;
}
