import { Agent, ExecutionStatus, IExecutionInput, IMemoryMessage, Tokens } from '../..';
import { Base } from '../base';
/**
 * Represents an execution of an agent in xpanderAI, including its input,
 * status, memory, and other related details.
 */
export declare class Execution extends Base {
    id: string;
    agentId: string;
    organizationId: string;
    input: IExecutionInput;
    status: ExecutionStatus;
    lastExecutedNodeId: string;
    memoryThreadId: string;
    parentExecution: string;
    workerId: string;
    result: string;
    llmTokens: Tokens;
    static initExecution(createdExecution: any): Execution;
    /**
     * Updates an execution with the specified delta changes.
     *
     * @param agent - The agent associated with the execution.
     * @param execution_id - The ID of the execution to update.
     * @param delta - A record of changes to apply to the execution.
     * @returns The updated execution object.
     */
    static update(agent: Agent, execution_id: string, delta: Record<string, any>): any;
    static create(agent: Agent, input: string, files: string[], workerId?: string, threadId?: string, parentExecutionId?: string, toolCallName?: string): any;
    static fetch(agent: Agent, executionId: string): any;
    static retrievePendingExecution(agent: Agent, workerId: string): any;
    /**
     * Constructs a new Execution instance.
     *
     * @param id - Unique identifier of the execution.
     * @param agentId - Identifier of the agent performing the execution.
     * @param organizationId - Identifier of the organization associated with the execution.
     * @param input - Input provided for the execution.
     * @param status - Current status of the execution.
     * @param lastExecutedNodeId - Identifier of the last executed node.
     * @param memoryThreadId - Identifier of the memory thread associated with the execution.
     * @param workerId - Identifier of the worker associated with the execution.
     */
    constructor(id: string, agentId: string, organizationId: string, input: IExecutionInput, status: ExecutionStatus, lastExecutedNodeId?: string, memoryThreadId?: string, parentExecution?: string, workerId?: string, result?: string, llmTokens?: Tokens);
    /**
     * Retrieves the input message formatted as a memory message.
     *
     * Combines text and file references into a single message object.
     *
     * @returns An object representing the user's input message.
     */
    get inputMessage(): IMemoryMessage;
}
