import { Agent } from '../agents';
import { Base } from '../base';
import { GraphItem } from './GraphItem';
/**
 * Represents a graph structure containing nodes related to an agent.
 *
 * @class Graph
 * @extends {Base}
 *
 * @param {Agent} agent - The agent associated with this graph.
 * @param {GraphItem[]} items - The list of graph items (nodes).
 *
 * @memberof xpander.ai
 */
export declare class Graph extends Base {
    private agent;
    private items;
    constructor(agent: Agent, items: GraphItem[]);
    /**
     * Finds a node in the graph by its item ID.
     *
     * @param {string} itemId - The item ID to search for.
     * @returns {GraphItem | undefined} The found graph item or undefined if not found.
     */
    findNodeByItemId(itemId: string): GraphItem | undefined;
    /**
     * Finds a node in the graph by its name.
     *
     * @param {string} name - The item ID to search for.
     * @returns {GraphItem | undefined} The found graph item or undefined if not found.
     */
    findNodeByName(name: string): GraphItem | undefined;
    /**
     * Finds a node in the graph by its node ID.
     *
     * @param {string} nodeId - The node ID to search for.
     * @returns {GraphItem | undefined} The found graph item or undefined if not found.
     */
    findNodeByNodeId(nodeId: string): GraphItem | undefined;
    /**
     * Gets the list of nodes in the graph.
     *
     * @returns {GraphItem[]} The list of graph items.
     */
    get nodes(): GraphItem[];
    /**
     * Checks whether the graph is empty.
     *
     * @returns {boolean} True if the graph is empty, false otherwise.
     */
    get isEmpty(): boolean;
    /**
     * Gets the last node in the graph.
     *
     * @returns {GraphItem | undefined} The last graph item or undefined if the graph is empty.
     */
    get lastNode(): GraphItem | undefined;
    /**
     * Adds a new node to the graph.
     *
     * @param {Agent | GraphItem} node - The node to add, which can be an agent or a graph item.
     * @returns {GraphItem} The newly added graph item.
     * @throws {Error} If adding the node fails.
     */
    addNode(node: Agent | GraphItem): GraphItem;
    /**
     * Resets the graph for the associated agent.
     *
     * @throws {Error} If resetting the graph fails.
     */
    reset(): void;
    get rootNode(): GraphItem | undefined;
    get textual(): string;
}
