import { BaseLLMProvider } from './shared/baseProvider';
import { LLMProvider } from '../constants/llmProvider';
import { ToolCall } from '../core/tools';
import { IBedrockTool } from '../types';
/**
 * Represents the Amazon Bedrock LLM provider, handling tool calls and model-specific processing.
 */
export declare class AmazonBedrock extends BaseLLMProvider {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Transforms a string to a valid AWS identifier by replacing non-alphanumeric characters
     * with underscores and ensuring it starts with a letter.
     * @param inputString - The string to transform.
     * @returns The transformed AWS-compatible string.
     */
    static transformToValidAWSIdentifier(inputString: string): string;
    /**
     * Extracts tool calls from an Amazon Bedrock LLM response.
     * @param llmResponse - The response object from Amazon Bedrock.
     * @returns An array of ToolCall objects extracted from the response.
     * @throws Error if the response format is invalid.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
    /**
     * Post-processes tools to ensure compliance with the IBedrockTool interface,
     * adjusting names to be AWS-compatible where necessary.
     * @param tools - The tools to post-process.
     * @returns An array of post-processed tools.
     */
    postProcessTools(tools: any[]): IBedrockTool[];
}
