import { BaseOpenAISDKHandler } from './shared/baseOpenAI';
import { LLMProvider } from '../constants/llmProvider';
import { ToolCall } from '../core/tools';
/**
 * Handles interactions with the LangChain LLM provider, extracting tool calls from responses.
 */
export declare class LangChain extends BaseOpenAISDKHandler {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Extracts tool calls from a LangChain LLM response.
     * @param llmResponse - The response object from LangChain.
     * @returns An array of ToolCall objects extracted from the response.
     * @throws Error if the response format is invalid.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
}
