import { LLMProvider } from '../constants/llmProvider';
import { BaseLLMProvider } from './shared/baseProvider';
import { ToolCall } from '../core/tools';
/**
 * Handles interactions with the Ollama LLM provider, including tool post-processing
 * to append default parameters when necessary.
 */
export declare class Ollama extends BaseLLMProvider {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Extracts tool calls from an Ollama LLM response.
     * @param llmResponse - The response object from Ollama.
     * @returns An array of ToolCall objects extracted from the response.
     * @throws Error if the response format is invalid.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
    /**
     * Post-processes tools to append default parameters, ensuring compatibility with Ollama's strict requirements.
     * @param tools - The tools to post-process.
     * @returns An array of post-processed tools with default parameters applied where necessary.
     */
    postProcessTools(tools: any[]): any[];
}
