import { BaseLLMProvider } from './baseProvider';
import { IMemoryMessage } from '../..';
import { LLMProvider } from '../../constants/llmProvider';
import { ToolCall } from '../../core/tools';
/**
 * Handles interaction with OpenAI SDK, processing responses to extract tool calls.
 */
export declare class BaseOpenAISDKHandler extends BaseLLMProvider {
    /**
     * Determines if this handler should manage the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the handler should manage the provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Utility functions for converting LLM responses and xpanderAI messages into compatible formats.
     */
    static extractMessages(llmResponse: any): IMemoryMessage[];
    /**
     * Converts xpanderAI memory messages into LLM-compatible message formats.
     *
     * @param xpanderMessages - An array of xpanderAI memory messages.
     * @returns An array of messages formatted for LLM compatibility.
     */
    static convertMessages(xpanderMessages: IMemoryMessage[]): any[];
    /**
     * Extracts tool calls from an OpenAI LLM response.
     * @param llmResponse - The response object from the OpenAI LLM.
     * @returns An array of ToolCall objects extracted from the response.
     * @throws Error if the response format is invalid.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
}
